Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(883)

Unified Diff: remoting/proto/control.proto

Issue 2021773002: Use only DIPs size in ClientResolution. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/protocol/host_control_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/proto/control.proto
diff --git a/remoting/proto/control.proto b/remoting/proto/control.proto
index f6922f177ac13d268ef8680759b2ecb00bd2f9ef..72c843df48a2e44d1190056ceb8f8def59d65be6 100644
--- a/remoting/proto/control.proto
+++ b/remoting/proto/control.proto
@@ -11,13 +11,13 @@ option optimize_for = LITE_RUNTIME;
package remoting.protocol;
message ClientResolution {
- // Legacy width and height of the client in Density-Independent Pixels
+ // Width and height of the client in Density-Independent Pixels
optional int32 dips_width = 1;
optional int32 dips_height = 2;
- // Width and height of the client in device pixels.
- optional int32 width = 3;
- optional int32 height = 4;
+ // Deprecated width and height of the client in device pixels.
+ optional int32 width_deprecated = 3;
+ optional int32 height_deprecated = 4;
// Horizontal and vertical DPI of the screen. If either of these is zero or
// unset, the corresponding DPI should be assumed to be 96 (Windows' default)
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/protocol/host_control_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698